@@ -1,3 +1,15 @@
+# MIT License
+# Copyright (c) 2023 Alex Butler
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
 """Primary alto engine."""
 import atexit
 import datetime
@@ -20,12 +32,10 @@ from hashlib import md5, sha1
 from pathlib import Path
 
 import fsspec
-import pex.bin.pex
 from doit.cmd_base import DoitCmdBase as AltoCmdBase
 from doit.cmd_base import TaskLoader2 as DoitEngine
 from doit.loader import generate_tasks
 from doit.tools import config_changed
-from dynaconf import Dynaconf
 from dynaconf.utils.boxing import DynaBox
 from fsspec.implementations.dirfs import DirFileSystem
 
@@ -71,6 +81,10 @@ class AltoCmd(str, Enum):
     INVOKE = "invoke"
     REPL = "repl"
 
+    def __str__(self) -> str:
+        """Return the string representation of the command."""
+        return self.value
+
 
 class AltoConfiguration:
     """A wrapper around dynaconf that provides alto specific accessors."""
@@ -480,6 +494,8 @@ class AltoTaskEngine(DoitEngine):
     ) -> None:
         """Initialize the alto task engine."""
         super().__init__()
+        from dynaconf import Dynaconf
+
         self.alto = Dynaconf(
             settings_files=[root_dir / f"alto.{fmt}" for fmt in SUPPORTED_CONFIG_FORMATS],
             secrets=[root_dir / f"alto.secrets.{fmt}" for fmt in SUPPORTED_CONFIG_FORMATS],
@@ -553,7 +569,9 @@ class AltoTaskEngine(DoitEngine):
         def build_pex(plugin: AltoPlugin) -> None:
             """Build a pex from the requirements string."""
             output = self.filesystem.executable_path(plugin.pex_name)
-            # Build the pex
+            # Build the pex (deferred import speeds up the CLI)
+            import pex.bin.pex
+
             try:
                 pex.bin.pex.main(["-o", output, "--no-emit-warnings", *plugin.pip_url.split()])
             except SystemExit:
@@ -689,12 +707,13 @@ class AltoTaskEngine(DoitEngine):
             Path(catalog).parent.mkdir(parents=True, exist_ok=True)
             try:
                 # Run the tap in discovery mode
-                subprocess.run(
-                    [bin, "--config", config, "--discover"],
-                    stdout=open(catalog, "w"),
-                    check=True,
-                    env={**os.environ, **tap.environment},
-                )
+                with open(catalog, "w") as f:
+                    subprocess.run(
+                        [bin, "--config", config, "--discover"],
+                        stdout=f,
+                        check=True,
+                        env={**os.environ, **tap.environment},
+                    )
             except subprocess.CalledProcessError:
                 # If the tap fails to discover, delete the compromised catalog
                 os.remove(catalog)
@@ -1540,9 +1559,13 @@ class AltoTaskEngine(DoitEngine):
                         "name": f"param{i}",
                         "long": arg.lstrip("-"),
                         "default": "",
-                        "type": bool
-                        if len(args) > i + 1 and args[1 + i].startswith("-") or len(args) == i + 1
-                        else str,
+                        "type": (
+                            bool
+                            if len(args) > i + 1
+                            and args[1 + i].startswith("-")
+                            or len(args) == i + 1
+                            else str
+                        ),
                     }
                     for i, arg in enumerate(args)
                     if arg.startswith("-")
