@@ -1,4 +1,16 @@
 #! /usr/bin/env python3
+# MIT License
+# Copyright (c) 2023 Alex Butler
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
 """Main entry point for the CLI."""
 import os
 import sys
@@ -75,14 +87,14 @@ class AltoInit(Command):
                         "default": {
                             "project_name": os.urandom(4).hex(),
                             "extensions": [],
-                            "namespace": "raw",
+                            "load_path": "raw",
                             "taps": {
                                 "tap-carbon-intensity": {
                                     "pip_url": (
                                         "git+https://gitlab.com/meltano/tap-carbon-intensity.git"
                                         "#egg=tap_carbon_intensity"
                                     ),
-                                    "namespace": "carbon_intensity",
+                                    "load_path": "carbon_intensity",
                                     "config": {
                                         "any_key": (
                                             "<this will end up in a config.json passed to the tap>"
